job "sonarr" {
  schedule = "@daily"

  config {
    repo = "s3://backups-minio.agnosticfront.thefij:8443/nomad/sonarr"
    passphrase = env("BACKUP_PASSPHRASE")

    options {
      InsecureTls = true
    }
  }

  task "Backup main database" {
    postgres "Backup database" {
      hostname       = env("POSTGRES_HOST")
      port           = env("POSTGRES_PORT")
      username       = env("POSTGRES_USER")
      password       = env("POSTGRES_PASSWORD")
      database       = "sonarr"
      no_tablespaces = true
      dump_to        = "/data/nas-container/sonarr/Backups/dump-sonarr.sql"
    }
  }

  task "Backup logs database" {
    postgres "Backup database" {
      hostname       = env("POSTGRES_HOST")
      port           = env("POSTGRES_PORT")
      username       = env("POSTGRES_USER")
      password       = env("POSTGRES_PASSWORD")
      database       = "sonarr-logs"
      no_tablespaces = true
      dump_to        = "/data/nas-container/sonarr/Backups/dump-sonarr-logs.sql"
    }
  }

  backup {
    paths = ["/data/nas-container/sonarr"]

    backup_opts {
      Exclude = [
        "sonarr_backup_*.zip",
        "/data/nas-container/sonarr/MediaCover",
        "/data/nas-container/sonarr/logs",
        "*.db",
        "*.db-shm",
        "*.db-wal",
      ]
      Host = "nomad"
    }

    restore_opts {
      Host = ["nomad"]
      # Because path is absolute
      Target = "/"
    }
  }

  forget {
    KeepLast = 2
    KeepDaily = 30
    KeepWeekly = 8
    KeepMonthly = 6
    KeepYearly = 2
    Prune = true
  }
}
