module "radarr" {
  source = "./service"

  name  = "radarr"
  image = "lscr.io/linuxserver/radarr:5.2.6"

  ingress      = true
  service_port = 7878
  use_wesher   = var.use_wesher
  ingress_middlewares = [
    "authelia@nomad"
  ]

  use_postgres = true
  postgres_bootstrap = {
    enabled = true
    databases = [
      "radarr",
      "radarr-logs",
    ]
  }

  env = {
    PGID = 100
    PUID = 1001
    TZ   = "America/Los_Angeles"
  }

  host_volumes = [
    {
      name      = "radarr-config"
      dest      = "/config"
      read_only = false
    },
    {
      name      = "media-write"
      dest      = "/media"
      read_only = false
    },
  ]

  resources = {
    cpu        = 500
    memory     = 500
    memory_max = 700
  }
}

resource "nomad_variable" "authelia_service_rules_radarr" {
  path = "authelia/access_control/service_rules/radarr"
  items = {
    name = "radarr"
    rule = <<EOH
policy: bypass
resources:
  - '^/api([/?].*)?$'
    EOH
  }
}
