module "sonarr" {
  source = "./service"

  name  = "sonarr"
  image = "lscr.io/linuxserver/sonarr:4.0.2"

  priority = 55

  ingress      = true
  service_port = 8989
  use_wesher   = var.use_wesher
  ingress_middlewares = [
    "authelia@nomad"
  ]

  use_postgres = true
  postgres_bootstrap = {
    enabled = true
    databases = [
      "sonarr",
      "sonarr-logs",
    ]
  }

  env = {
    PGID = 100
    PUID = 1001
    TZ   = "America/Los_Angeles"
  }

  host_volumes = [
    {
      name      = "sonarr-config"
      dest      = "/config"
      read_only = false
    },
    {
      name      = "media-write"
      dest      = "/media"
      read_only = false
    },
  ]

  resources = {
    cpu        = 100
    memory     = 500
    memory_max = 700
  }
}

resource "nomad_variable" "authelia_service_rules_sonarr" {
  path = "authelia/access_control/service_rules/sonarr"
  items = {
    name = "sonarr"
    rule = <<EOH
policy: bypass
resources:
  - '^/api([/?].*)?$'
    EOH
  }
}
